==> owncloud-calendar_0.7.3.orig.tar.gz: calendar-0.7.3/l10n/it.js <==
OC.L10N.register(
    "calendar",
    {
    "Not all calendars are completely cached" : "Non tutti i calendari sono mantenuti completamente in cache",
    "Everything seems to be completely cached" : "Tutto sembra essere mantenuto completamente in cache",
    "No calendars found." : "Nessun calendario trovato.",
    "No events found." : "Nessun evento trovato.",
    "Wrong calendar" : "Calendario sbagliato",
    "You do not have the permissions to edit this event." : "Non hai i permessi per modificare questo evento.",
    "The file contained either no events or all events are already saved in your calendar." : "Il file non conteneva alcun evento o tutti gli eventi erano già salvati nel tuo calendario.",
    "events have been saved in the new calendar" : "eventi sono stati salvati nel nuovo calendario",
    "Import failed" : "Importazione non riuscita",
    "events have been saved in your calendar" : "eventi sono stati salvati nel tuo calendario",
    "New Timezone:" : "Nuovo fuso orario:",
    "Timezone changed" : "Fuso orario cambiato",
    "Invalid request" : "Richiesta non valida",
    "Calendar" : "Calendario",
    "Error sending mail" : "Errore durante l'invio del messaggio",
    "Deletion failed" : "Eliminazione non riuscita",
    "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" : "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
    "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" : "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
    "Do you really want to delete this calendar?" : "Vuoi davvero eliminare questp calendario?",
    "group" : "gruppo",
    "can edit" : "può modificare",
    "can share" : "può condividere",
    "ddd" : "ddd",
    "ddd M/d" : "ddd d/M",
    "dddd M/d" : "dddd d/M",
    "MMMM yyyy" : "MMMM yyyy",
    "MMM d[ yyyy]{ '–'[ MMM] d yyyy}" : "d MMM[ yyyy]{ '–'d [ MMM] yyyy}",
    "dddd, MMM d, yyyy" : "dddd, d MMM yyyy",
    "Sunday" : "Domenica",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Gio.",
    "Fri." : "Ven.",
    "Sat." : "Sab.",
    "January" : "Gennaio",
    "February" : "Febbraio",
    "March" : "Marzo",
    "April" : "Aprile",
    "May" : "Maggio",
    "June" : "Giugno",
    "July" : "Luglio",
    "August" : "Agosto",
    "September" : "Settembre",
    "October" : "Ottobre",
    "November" : "Novembre",
    "December" : "Dicembre",
    "Jan." : "Gen.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mag.",
    "Jun." : "Giu.",
    "Jul." : "Lug.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Ott.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "All day" : "Tutti il giorno",
    "New Calendar" : "Nuovo calendario",
    "Missing or invalid fields" : "Campi mancanti o non validi",
    "Title" : "Titolo",
    "From Date" : "Dal giorno",
    "From Time" : "Ora iniziale",
    "To Date" : "Al giorno",
    "To Time" : "Ora finale",
    "The event ends before it starts" : "L'evento finisce prima d'iniziare",
    "There was a database fail" : "Si è verificato un errore del database",
    "Interval is not valid. It must be a positive integer!" : "L'intervallo non è valido, Deve essere un intero positivo.",
    "Birthday" : "Compleanno",
    "Business" : "Azienda",
    "Call" : "Chiama",
    "Clients" : "Clienti",
    "Deliverer" : "Consegna",
    "Holidays" : "Vacanze",
    "Ideas" : "Idee",
    "Journey" : "Viaggio",
    "Jubilee" : "Anniversario",
    "Meeting" : "Riunione",
    "Other" : "Altro",
    "Personal" : "Personale",
    "Projects" : "Progetti",
    "Questions" : "Domande",
    "Work" : "Lavoro",
    "by" : "da",
    "unnamed" : "senza nome",
    "You do not have the permissions to update this calendar." : "Non hai i permessi per aggiornare questo calendario.",
    "You do not have the permissions to delete this calendar." : "Non hai i permessi per eliminare questo calendario.",
    "You do not have the permissions to add to this calendar." : "Non hai i permessi per aggiungere a questo calendario.",
    "You do not have the permissions to add events to this calendar." : "Non hai i permessi per aggiungere eventi a questo calendario.",
    "You cannot add non-public events to a shared calendar." : "Non puoi aggiungere eventi non pubblici a un calendario condiviso.",
    "You do not have the permissions to delete this event." : "Non hai i permessi per eliminare questo evento.",
    "Busy" : "Occupato",
    "Show full event" : "Mostra evento completo",
    "Show only busy" : "Mostra solo occupato",
    "Hide event" : "Nascondi evento",
    "Does not repeat" : "Non ripetere",
    "Daily" : "Giornaliero",
    "Weekly" : "Settimanale",
    "Every Weekday" : "Ogni giorno della settimana",
    "Bi-Weekly" : "Ogni due settimane",
    "Monthly" : "Mensile",
    "Yearly" : "Annuale",
    "never" : "mai",
    "by occurrences" : "per occorrenze",
    "by date" : "per data",
    "by monthday" : "per giorno del mese",
    "by weekday" : "per giorno della settimana",
    "events week of month" : "settimana del mese degli eventi",
    "first" : "primo",
    "second" : "secondo",
    "third" : "terzo",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "last" : "ultimo",
    "by events date" : "per data evento",
    "by yearday(s)" : "per giorno/i dell'anno",
    "by weeknumber(s)" : "per numero/i settimana",
    "by day and month" : "per giorno e mese",
    "Contact birthdays" : "Compleanni dei contatti",
    "Date" : "Data",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "Today" : "Oggi",
    "CalDav Link" : "Collegamento CalDav",
    "Timezone" : "Fuso orario",
    "Update timezone automatically" : "Aggiorna automaticamente il fuso orario",
    "Time format" : "Formato orario",
    "24h" : "24h",
    "12h" : "12h",
    "Start week on" : "La settimana inizia il",
    "Cache" : "Cache",
    "Clear cache for repeating events" : "Cancella gli eventi che si ripetono dalla cache",
    "Primary CalDAV address" : "Indirizzo CalDAV principale",
    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X",
    "Share Calendar" : "Condividi calendario",
    "Download" : "Scarica",
    "Edit" : "Modifica",
    "Delete" : "Elimina",
    "New calendar" : "Nuovo calendario",
    "Edit calendar" : "Modifica calendario",
    "Edit event" : "Modifica evento",
    "Save event" : "Salva evento",
    "Delete event" : "Elimina evento",
    "Eventinfo" : "Informazioni evento",
    "Repeating" : "Ripetizione",
    "Alarm" : "Avviso",
    "Attendees" : "Partecipanti",
    "Share" : "Condividi",
    "Title of the Event" : "Titolo dell'evento",
    "from" : "da",
    "to" : "a",
    "All Day Event" : "Evento che occupa tutta la giornata",
    "Advanced options" : "Opzioni avanzate",
    "Location" : "Luogo",
    "Categories (separate by comma)" : "Categorie (separate da virgola)",
    "Edit categories" : "Modifica le categorie",
    "Description" : "Descrizione",
    "Export event" : "Esporta evento",
    "Repeat" : "Ripeti",
    "Advanced" : "Avanzate",
    "Select weekdays" : "Seleziona i giorni della settimana",
    "Select days" : "Seleziona i giorni",
    "and the events day of year." : "e il giorno dell'anno degli eventi.",
    "and the events day of month." : "e il giorno del mese degli eventi.",
    "Select months" : "Seleziona i mesi",
    "Select weeks" : "Seleziona le settimane",
    "and the events week of year." : "e la settimana dell'anno degli eventi.",
    "Interval" : "Intervallo",
    "End" : "Fine",
    "occurrences" : "occorrenze",
    "Visibility to people shared with" : "Visibile alle persone con cui hai condiviso",
    "create a new calendar" : "Crea un nuovo calendario",
    "Import a calendar file" : "Importa un file di calendario",
    "Please choose a calendar" : "Scegli un calendario",
    "Name of new calendar" : "Nome del nuovo calendario",
    "Take an available name!" : "Usa un nome disponibile!",
    "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." : "Un calendario con questo nome esiste già. Se continui, i due calendari saranno uniti.",
    "Remove all events from the selected calendar" : "Rimuovi tutti gli eventi dal calendario selezionato",
    "Import" : "Importa",
    "Close Dialog" : "Chiudi la finestra di dialogo",
    "Create a new event" : "Crea un nuovo evento",
    "Create event" : "Crea evento",
    "Share with user or group" : "Condividi con utente o gruppo",
    "Unshare" : "Rimuovi condivisione",
    "Not shared with anyone" : "Non condiviso con altri",
    "Send Email" : "Invia email",
    "Shared via calendar" : "Condiviso tramite calendario",
    "Not shared with anyone via calendar" : "Non condiviso con altri tramite calendario",
    "View an event" : "Visualizza un evento",
    "Category" : "Categoria",
    "No categories selected" : "Nessuna categoria selezionata",
    "%s of %s" : "%s di %s",
    "Access Class" : "Classe di accesso",
    "From" : "Da",
    "at" : "alle",
    "To" : "A"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-calendar_0.8.1.orig.tar.gz: calendar-0.8.1/l10n/it.js <==
OC.L10N.register(
    "calendar",
    {
    "Not all calendars are completely cached" : "Non tutti i calendari sono mantenuti completamente in cache",
    "Everything seems to be completely cached" : "Tutto sembra essere mantenuto completamente in cache",
    "No calendars found." : "Nessun calendario trovato.",
    "No events found." : "Nessun evento trovato.",
    "Wrong calendar" : "Calendario errato",
    "You do not have the permissions to edit this event." : "Non hai i permessi per modificare questo evento.",
    "The file contained either no events or all events are already saved in your calendar." : "Il file non conteneva alcun evento o tutti gli eventi erano già salvati nel tuo calendario.",
    "events have been saved in the new calendar" : "eventi sono stati salvati nel nuovo calendario",
    "Import failed" : "Importazione non riuscita",
    "New Timezone:" : "Nuovo fuso orario:",
    "Timezone changed" : "Fuso orario cambiato",
    "Invalid request" : "Richiesta non valida",
    "Calendar" : "Calendario",
    "Error sending mail" : "Errore durante l'invio del messaggio",
    "Deletion failed" : "Eliminazione non riuscita",
    "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" : "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
    "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" : "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
    "Do you really want to delete this calendar?" : "Vuoi davvero eliminare questo calendario?",
    "group" : "gruppo",
    "can edit" : "può modificare",
    "can share" : "può condividere",
    "ddd" : "ddd",
    "ddd M/d" : "ddd d/M",
    "dddd M/d" : "dddd d/M",
    "MMMM yyyy" : "MMMM yyyy",
    "MMM d[ yyyy]{ '–'[ MMM] d yyyy}" : "d MMM[ yyyy]{ '–'d [ MMM] yyyy}",
    "dddd, MMM d, yyyy" : "dddd, d MMM yyyy",
    "Sunday" : "Domenica",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Gio.",
    "Fri." : "Ven.",
    "Sat." : "Sab.",
    "January" : "Gennaio",
    "February" : "Febbraio",
    "March" : "Marzo",
    "April" : "Aprile",
    "May" : "Maggio",
    "June" : "Giugno",
    "July" : "Luglio",
    "August" : "Agosto",
    "September" : "Settembre",
    "October" : "Ottobre",
    "November" : "Novembre",
    "December" : "Dicembre",
    "Jan." : "Gen.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mag.",
    "Jun." : "Giu.",
    "Jul." : "Lug.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Ott.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "All day" : "Tutti il giorno",
    "New Calendar" : "Nuovo calendario",
    "Missing or invalid fields" : "Campi mancanti o non validi",
    "Title" : "Titolo",
    "From Date" : "Dal giorno",
    "From Time" : "Ora iniziale",
    "To Date" : "Al giorno",
    "To Time" : "Ora finale",
    "The event ends before it starts" : "L'evento finisce prima d'iniziare",
    "There was a database fail" : "Si è verificato un errore del database",
    "Interval is not valid. It must be a positive integer!" : "L'intervallo non è valido, Deve essere un intero positivo.",
    "Import" : "Importa",
    "Shared" : "Condiviso",
    "Error" : "Errore",
    "Error while sharing" : "Errore durante la condivisione",
    "Error while unsharing" : "Errore durante la rimozione della condivisione",
    "Error while changing permissions" : "Errore durante la modifica dei permessi",
    "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
    "Shared with you by {owner}" : "Condiviso con te da {owner}",
    "Share with users or groups …" : "Condividi con utenti o gruppi...",
    "Share with users, groups or remote users …" : "Condividi con utenti, gruppi o utenti remoti...",
    "Share" : "Condividi",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Condividi con persone su altri ownCloud utilizzando la sintassi nomeutente@esempio.com/owncloud",
    "Share link" : "Condividi collegamento",
    "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
    "Link" : "Collegamento",
    "Password protect" : "Proteggi con password",
    "Password" : "Password",
    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
    "Allow editing" : "Consenti la modifica",
    "Email link to person" : "Invia collegamento tramite email",
    "Send" : "Invia",
    "Set expiration date" : "Imposta data di scadenza",
    "Expiration" : "Scadenza",
    "Expiration date" : "Data di scadenza",
    "An error occured. Please try again" : "Si è verificato un errore. Prova ancora",
    "Adding user..." : "Aggiunta utente in corso...",
    "remote" : "remota",
    "Resharing is not allowed" : "La ri-condivisione non è consentita",
    "Shared in {item} with {user}" : "Condiviso in {item} con {user}",
    "Unshare" : "Rimuovi condivisione",
    "notify by email" : "notifica tramite email",
    "access control" : "controllo d'accesso",
    "create" : "crea",
    "change" : "cambia",
    "delete" : "elimina",
    "Password protected" : "Protetta da password",
    "Error unsetting expiration date" : "Errore durante la rimozione della data di scadenza",
    "Error setting expiration date" : "Errore durante l'impostazione della data di scadenza",
    "Sending ..." : "Invio in corso...",
    "Email sent" : "Email inviata",
    "Warning" : "Avviso",
    "Birthday" : "Compleanno",
    "Business" : "Azienda",
    "Call" : "Chiama",
    "Clients" : "Clienti",
    "Deliverer" : "Consegna",
    "Holidays" : "Vacanze",
    "Ideas" : "Idee",
    "Journey" : "Viaggio",
    "Jubilee" : "Anniversario",
    "Meeting" : "Riunione",
    "Other" : "Altro",
    "Personal" : "Personale",
    "Projects" : "Progetti",
    "Questions" : "Domande",
    "Work" : "Lavoro",
    "by" : "da",
    "unnamed" : "senza nome",
    "You do not have the permissions to update this calendar." : "Non hai i permessi per aggiornare questo calendario.",
    "You do not have the permissions to delete this calendar." : "Non hai i permessi per eliminare questo calendario.",
    "You do not have the permissions to add to this calendar." : "Non hai i permessi per aggiungere a questo calendario.",
    "You do not have the permissions to add events to this calendar." : "Non hai i permessi per aggiungere eventi a questo calendario.",
    "You cannot add non-public events to a shared calendar." : "Non puoi aggiungere eventi non pubblici a un calendario condiviso.",
    "You do not have the permissions to delete this event." : "Non hai i permessi per eliminare questo evento.",
    "Busy" : "Occupato",
    "Show full event" : "Mostra evento completo",
    "Show only busy" : "Mostra solo occupato",
    "Hide event" : "Nascondi evento",
    "Does not repeat" : "Non ripetere",
    "Daily" : "Giornaliero",
    "Weekly" : "Settimanale",
    "Every Weekday" : "Ogni giorno della settimana",
    "Bi-Weekly" : "Ogni due settimane",
    "Monthly" : "Mensile",
    "Yearly" : "Annuale",
    "never" : "mai",
    "by occurrences" : "per occorrenze",
    "by date" : "per data",
    "by monthday" : "per giorno del mese",
    "by weekday" : "per giorno della settimana",
    "events week of month" : "settimana del mese degli eventi",
    "first" : "primo",
    "second" : "secondo",
    "third" : "terzo",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "last" : "ultimo",
    "by events date" : "per data evento",
    "by yearday(s)" : "per giorno/i dell'anno",
    "by weeknumber(s)" : "per numero/i settimana",
    "by day and month" : "per giorno e mese",
    "Contact birthdays" : "Compleanni dei contatti",
    "Date" : "Data",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "Today" : "Oggi",
    "CalDav Link" : "Collegamento CalDav",
    "Timezone" : "Fuso orario",
    "Update timezone automatically" : "Aggiorna automaticamente il fuso orario",
    "Time format" : "Formato orario",
    "24h" : "24h",
    "12h" : "12h",
    "Start week on" : "La settimana inizia il",
    "Cache" : "Cache",
    "Clear cache for repeating events" : "Cancella gli eventi che si ripetono dalla cache",
    "Primary CalDAV address" : "Indirizzo CalDAV principale",
    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X",
    "Share Calendar" : "Condividi calendario",
    "Download" : "Scarica",
    "Edit" : "Modifica",
    "Delete" : "Elimina",
    "New calendar" : "Nuovo calendario",
    "Edit calendar" : "Modifica calendario",
    "Edit event" : "Modifica evento",
    "Save event" : "Salva evento",
    "Delete event" : "Elimina evento",
    "Eventinfo" : "Informazioni evento",
    "Repeating" : "Ripetizione",
    "Alarm" : "Avviso",
    "Attendees" : "Partecipanti",
    "Title of the Event" : "Titolo dell'evento",
    "from" : "da",
    "to" : "a",
    "All Day Event" : "Evento che occupa tutta la giornata",
    "Advanced options" : "Opzioni avanzate",
    "Location" : "Luogo",
    "Categories (separate by comma)" : "Categorie (separate da virgola)",
    "Edit categories" : "Modifica le categorie",
    "Description" : "Descrizione",
    "Export event" : "Esporta evento",
    "Repeat" : "Ripeti",
    "Advanced" : "Avanzate",
    "Select weekdays" : "Seleziona i giorni della settimana",
    "Select days" : "Seleziona i giorni",
    "and the events day of year." : "e il giorno dell'anno degli eventi.",
    "and the events day of month." : "e il giorno del mese degli eventi.",
    "Select months" : "Seleziona i mesi",
    "Select weeks" : "Seleziona le settimane",
    "and the events week of year." : "e la settimana dell'anno degli eventi.",
    "Interval" : "Intervallo",
    "End" : "Fine",
    "occurrences" : "occorrenze",
    "Visibility to people shared with" : "Visibile alle persone con cui hai condiviso",
    "create a new calendar" : "Crea un nuovo calendario",
    "Import a calendar file" : "Importa un file di calendario",
    "Please choose a calendar" : "Scegli un calendario",
    "Name of new calendar" : "Nome del nuovo calendario",
    "Take an available name!" : "Usa un nome disponibile!",
    "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." : "Un calendario con questo nome esiste già. Se continui, i due calendari saranno uniti.",
    "Remove all events from the selected calendar" : "Rimuovi tutti gli eventi dal calendario selezionato",
    "Close Dialog" : "Chiudi la finestra di dialogo",
    "Create a new event" : "Crea un nuovo evento",
    "Create event" : "Crea evento",
    "Share with user or group" : "Condividi con utente o gruppo",
    "Not shared with anyone" : "Non condiviso con altri",
    "Send Email" : "Invia email",
    "Shared via calendar" : "Condiviso tramite calendario",
    "Not shared with anyone via calendar" : "Non condiviso con altri tramite calendario",
    "View an event" : "Visualizza un evento",
    "Category" : "Categoria",
    "No categories selected" : "Nessuna categoria selezionata",
    "%s of %s" : "%s di %s",
    "Access Class" : "Classe di accesso",
    "From" : "Da",
    "at" : "alle",
    "To" : "A"
},
"nplurals=2; plural=(n != 1);");
